@@ -13,7 +13,7 @@ package MooX::Options;
 use strict;
 use warnings;
 
-our $VERSION = '1.8';    # VERSION
+our $VERSION = '1.9';    # VERSION
 use Carp;
 use Data::Dumper;
 use Getopt::Long 2.38;
@@ -223,7 +223,7 @@ MooX::Options - add option keywords to your Moo object
 
 =head1 VERSION
 
-version 1.8
+version 1.9
 
 =head1 MooX::Options
 
@@ -470,12 +470,6 @@ Ex :
 
 =head1 BUGS
 
-Any bugs or evolution can be submit here :
-
-L<Github|https://github.com/celogeek/MooX-Options>
-
-=head1 BUGS
-
 Please report any bugs or feature requests on the bugtracker website
 https://github.com/celogeek/MooX-Options/issues
 
